@@ -16,6 +16,7 @@ This module provides bases classes for tables management.
 """
 
 import json
+
 from pyramid.decorator import reify
 from zope.component import queryMultiAdapter
 from zope.interface import implementer
@@ -37,16 +38,20 @@ from pyams_utils.list import boolean_iter
 from pyams_utils.url import absolute_url
 from pyams_viewlet.viewlet import ViewContentProvider
 from pyams_zmi.interfaces.table import IInnerTable, IMultipleTableView, IReorderColumn, \
-    ITableAdminView, ITableElementEditor, ITableGroupSwitcher, ITableView
+    ITableAdminView, ITableElementEditor, ITableGroupSwitcher, ITableView, ITableAttributes
 from pyams_zmi.utils import get_object_hint, get_object_icon, get_object_label
 from pyams_zmi.view import InnerAdminView
 
-
 __docformat__ = 'restructuredtext'
 
 from pyams_zmi import _  # pylint: disable=ungrouped-imports
 
 
+def get_name(element):
+    """Element name getter"""
+    return getattr(element, '__name__', None)
+
+
 def get_table_id(table, context=None):
     """Table ID getter"""
     if context is None:
@@ -69,11 +74,6 @@ def get_row_id(table, element, context=None):
     return f'{table.id}::{ICacheKeyValue(element)}'
 
 
-def get_row_name(element):
-    """Row name getter"""
-    return getattr(element, '__name__', None)
-
-
 def get_row_editor(table, element):
     """Row editor getter"""
     return queryMultiAdapter((element, table.request, table), ITableElementEditor)
@@ -127,7 +127,7 @@ def get_ordered_data_attributes(source, container, request, target='reorder.json
             'data-ams-reorder-url': target
         })
         source.setdefault('tr', {}).update({
-            'data-ams-row-value': lambda row, col: get_row_name(row)
+            'data-ams-row-value': lambda row, col: get_name(row)
         })
         source.setdefault('td', {}).update({
             'data-order': lambda x, col: list(container.keys()).index(x.__name__)
@@ -162,14 +162,14 @@ class Table(ObjectDataManagerMixin, BaseTable):
         These attributes are to be use with DataTables plug-in, and can be overridden in
         subclasses.
         """
-        return {
+        result = {
             'table': {
                 'id': self.id,
                 'data-ams-location': absolute_url(self.context, self.request)
             },
             'tr': {
                 'id': lambda row, col: self.get_row_id(row),
-                'data-ams-element-name': lambda row, col: get_row_name(row),
+                'data-ams-element-name': lambda row, col: get_name(row),
                 'data-ams-url': lambda row, col: getattr(get_row_editor(self, row), 'href', None),
                 'data-toggle':
                     lambda row, col: 'modal' if getattr(get_row_editor(self, row),
@@ -177,11 +177,15 @@ class Table(ObjectDataManagerMixin, BaseTable):
                     else None
             },
             'th': {
-                'data-ams-column-name': lambda row, col: row.__name__,
+                'data-ams-column-name': lambda row, col: get_name(row),
                 'data-ams-sortable': get_column_sort,
                 'data-ams-type': get_column_type
             }
         }
+        for name, adapter in self.request.registry.getAdapters((self.context, self.request, self),
+                                                               ITableAttributes):
+            adapter.update_attributes(result)
+        return result
 
     def get_row_id(self, row):
         """Row ID getter"""
